<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Block Attachments
    Version ........ 0.4
    Purpose ........ Allows an admin to block any types of attachments

*******************************************************************************/

   global $optpage_blocks, $username;
   $admins = array();
   $file = fopen(SM_PATH . 'config/admins',r);
   while (!feof($file)){
      $x = trim(fgets($file));
      if (strlen($x)>0)
         $admins[]= $x;
   }

   $auth = in_array($username, $admins);
   if (!$auth) return;
   bindtextdomain('block_attach', SM_PATH . 'plugins/block_attach/locale');
   textdomain('block_attach');
   $optpage_blocks[] = array (
        'name' => _("Block Attachments"),
        'url'  => SM_PATH . 'plugins/block_attach/options.php',
        'desc' => _("These settings allow you to block certain types of attachments."),
        'js'   => false
   );
   textdomain('squirrelmail');
?>